@@ -6,4 +6,7 @@
 from .email import EmailParam
 
 ## Domains
-from .domain import DomainParam
\ No newline at end of file
+from .domain import DomainParam
+
+## URL
+from .url import UrlParam
